import { Component, Input, Output, EventEmitter, forwardRef } from '@angular/core';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
var DropdownComponent = (function () {
    function DropdownComponent() {
        this.textField = 'text';
        this.idField = 'id';
        this.disabled = false;
        this.placeHolder = '';
        this.multiple = false;
        this.change = new EventEmitter();
        this.menuPanelState = 'inactive';
        this._active = false;
        this._onChange = function (_) { };
        this._onTouched = function () { };
        this.id = "lsu_dropdown_" + Math.random();
    }
    Object.defineProperty(DropdownComponent.prototype, "active", {
        get: function () {
            return this._active;
        },
        set: function (v) {
            this._active = !!v;
            if (this._active) {
                this.menuPanelState = 'active';
            }
            else {
                this.menuPanelState = 'inactive';
            }
        },
        enumerable: true,
        configurable: true
    });
    DropdownComponent.prototype.writeValue = function (value) {
        var _this = this;
        if (value) {
            if (this.multiple) {
                var selectedItems = [];
                if (Array.isArray(value)) {
                    var ids_1 = value;
                    if (this.idField) {
                        ids_1 = value.map(function (x) { return x[_this.idField]; }).filter(function (x) { return !!x; });
                    }
                    selectedItems = (this.data || []).filter(function (x) {
                        return ids_1.indexOf(_this.idField ? (x[_this.idField] || x) : x) !== -1;
                    });
                }
                this.selectedItem = selectedItems;
            }
            else {
                var isObj_1 = typeof value === 'object';
                var selectedItems = (this.data || []).filter(function (x) {
                    return (_this.idField && isObj_1) ? value[_this.idField] === x[_this.idField] : value === x;
                });
                this.selectedItem = selectedItems[0];
            }
        }
        else {
            this.selectedItem = value;
        }
    };
    DropdownComponent.prototype.registerOnChange = function (fn) {
        this._onChange = fn;
    };
    DropdownComponent.prototype.registerOnTouched = function (fn) {
        this._onTouched = fn;
    };
    DropdownComponent.prototype.ngOnInit = function () {
    };
    DropdownComponent.prototype.onDocumentClick = function (event) {
        var id = event.target.id;
        if (this.active && id !== this.id) {
            this.active = false;
        }
    };
    DropdownComponent.prototype.toggleSelectPanel = function (event) {
        this.active = !this.active;
        if (event) {
            event.target.id = this.id;
        }
    };
    DropdownComponent.prototype.isSelected = function (item) {
        if (!this.selectedItem) {
            return false;
        }
        if (this.multiple) {
            var index = this.selectedItem.indexOf(item);
            return index !== -1;
        }
        else {
            return this.selectedItem === item;
        }
    };
    DropdownComponent.prototype.itemClick = function (item, event) {
        var value;
        if (this.multiple) {
            value = this.selectedItem || [];
            value.push(item);
            if (value.length === this.data.length) {
                this.toggleSelectPanel();
            }
        }
        else {
            value = item;
            this.toggleSelectPanel();
        }
        this.setValue(value);
        event.stopPropagation();
    };
    DropdownComponent.prototype.removeItem = function (item, event) {
        var value = this.selectedItem;
        var index = value.indexOf(item);
        if (index !== -1) {
            value.splice(index, 1);
        }
        this.setValue(value);
        event.stopPropagation();
    };
    DropdownComponent.prototype.setValue = function (value) {
        this.selectedItem = value;
        this._onChange(value);
        this.change.next(value);
    };
    DropdownComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lsu-dropdown',
                    styles: [".active,.visible{ display:block !important; }"],
                    host: {
                        '(document:click)': 'onDocumentClick($event)'
                    },
                    template: "\n      <div class=\"ui fluid selection dropdown\" [attr.id]=\"id\"\n           [ngClass]=\"{'active':active,'visible':active,'multiple':multiple,'disabled':disabled}\"\n           (click)=\"toggleSelectPanel($event)\">\n          <i class=\"dropdown icon\"></i>\n          <div class=\"default text\" *ngIf=\"!selectedItem || selectedItem.length == 0\">\n              {{ placeHolder }}\n          </div>\n          <div class=\"text\" *ngIf=\"selectedItem && !multiple\">\n              {{ selectedItem[textField] || selectedItem }}\n          </div>\n          <div *ngIf=\"selectedItem && multiple\">\n              <a class=\"ui label transition visible\" style=\"display: inline-block !important;\" *ngFor=\"let item of selectedItem\">\n                  {{ item[textField] || item }}\n                  <i class=\"delete icon\" (click)=\"removeItem(item, $event)\"></i>\n              </a>\n          </div>\n          <div class=\"menu visible\" #menuPanel [@menuPanelState]=\"menuPanelState\"\n               (@menuPanelState.start)=\"menuPanel.style.overflowY = 'hidden'\"\n               (@menuPanelState.done)=\"menuPanel.style.overflowY = 'auto'\">\n              <div class=\"item\" [class.active]=\"isSelected(item)\" [class.filtered]=\"isSelected(item) && multiple\" (click)=\"itemClick(item, $event)\" *ngFor=\"let item of data\">\n                {{ item[textField] || item }}\n              </div>\n          </div>\n      </div>\n  ",
                    animations: [
                        trigger('menuPanelState', [
                            state('inactive', style({
                                height: 0,
                                opacity: 0
                            })),
                            state('active', style({
                                height: '*',
                                opacity: 1
                            })),
                            transition('inactive <=> active', animate('200ms ease'))
                        ])
                    ],
                    providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(function () { return DropdownComponent; }),
                            multi: true
                        }]
                },] },
    ];
    /** @nocollapse */
    DropdownComponent.ctorParameters = function () { return []; };
    DropdownComponent.propDecorators = {
        "data": [{ type: Input },],
        "textField": [{ type: Input },],
        "idField": [{ type: Input },],
        "disabled": [{ type: Input },],
        "placeHolder": [{ type: Input },],
        "multiple": [{ type: Input },],
        "change": [{ type: Output },],
    };
    return DropdownComponent;
}());
export { DropdownComponent };
//# sourceMappingURL=dropdown.component.js.map